@@ -217,6 +217,10 @@ class TaskMessageContractor(Contractor):
         TxId: str = _detail.get('TxId')
         assert TxId and isinstance(TxId, str), f'invalid TxId: {TxId}'
         logger.info(f'successfully pushed a new contract: {TxId=}')
+        # The contract framework doesn't promise the sequence of contractors when
+        # they are pushed almost at the same time, so we have to apart them a little.
+        # TODO remove me when it changes.
+        time.sleep(0.2)
         return TxId
 
     def _pop_contract(self) -> Optional[dict]:
