@@ -8,9 +8,10 @@ sys.path.insert(0, PYTHONPATH)
 
 if True:
     from alphafed import logger
-    from alphafed.examples.fed_avg.demos import (DATA_OWNER_5_ID, DP, FED_IRM,
-                                                 SECURE, SGD, VANILLA,
-                                                 get_scheduler, get_task_id)
+    from alphafed.examples.fed_avg import DATA_OWNER_5_ID
+    from alphafed.examples.fed_avg.demos import (DP, FED_IRM, SECURE, SGD,
+                                                 VANILLA, get_scheduler,
+                                                 get_task_id)
 
 parser = argparse.ArgumentParser(description='Run data owner 5 demo.')
 parser.add_argument('-m', '--mode',
