@@ -739,7 +739,7 @@ class FedAvgScheduler(Scheduler, metaclass=ABCMeta):
     def _save_model(self):
         """Save latest model state."""
         os.makedirs(self._save_path, exist_ok=True)
-        with open(f'{os.path.join(self._save_path, "model.pt")}', 'wb') as f:
+        with open(f'{os.path.join(self._save_path, "model_ckt.pt")}', 'wb') as f:
             torch.save(self.state_dict(), f)
         self.push_log('Saved latest parameters locally.')
 
@@ -762,7 +762,7 @@ class FedAvgScheduler(Scheduler, metaclass=ABCMeta):
         report_file_path = os.path.abspath(report_file)
 
         # torch.jit doesn't work with a TemporaryFile
-        model_file = os.path.join(self._save_path, "scripted.pt")
+        model_file = os.path.join(self._save_path, "scripted_model.pt")
         model_scripted = torch.jit.trace(self.model, self._example_inputs)
         model_scripted.save(model_file)
         model_file_path = os.path.abspath(model_file)
