@@ -432,7 +432,6 @@ class HeteroNNHostScheduler(HeteroNNScheduler):
 
             self._switch_status(self._GETHORING)
             self._checkin()
-            time.sleep(1)  # TODO remove me
 
             self._switch_status(self._ID_INTERSECTION)
             self._make_id_intersection()
@@ -471,6 +470,19 @@ class HeteroNNHostScheduler(HeteroNNScheduler):
                                                     requester_id=_event.peer_id)
                 if all(check_in_status.values()):
                     break
+        # it takes seconds to send a response and to consume it in the remote side,
+        # meanwhile, more check in events may arrive soonly. So keep looking for a while.
+        # TODO Ugerly，refactory it!
+        countdown = 10
+        for _event in self.contractor.contract_events(timeout=countdown):
+            if isinstance(_event, CheckinEvent):
+                check_in_status[_event.peer_id] = True
+                self.push_log(f'Welcome a new partner ID: {_event.peer_id}.')
+                self.push_log(f'There are {sum(check_in_status.values())} partners now.')
+                self.contractor.respond_checkin(round=self._round,
+                                                host=self.id,
+                                                nonce=_event.nonce,
+                                                requester_id=_event.peer_id)
         self.push_log('All partners have gethored.')
 
     def _sync_state(self):
@@ -520,7 +532,6 @@ class HeteroNNHostScheduler(HeteroNNScheduler):
         self._start_round()
         self.infer_model.train()
         self.feature_model.train()
-        time.sleep(1)  # TODO remove me
         for _feature_batch, _labels in self.iterate_train_feature(
             self.feature_model, self.train_ids
         ):
@@ -632,7 +643,6 @@ class HeteroNNHostScheduler(HeteroNNScheduler):
 
         self.push_log('Skip or close a round of testing.')
         self.contractor.close_test_round(round=self._round)
-        time.sleep(1)  # TODO remove me
 
     def _wait_for_testing_features(self):
         """Wait for collecting test dataset features."""
