@@ -664,7 +664,6 @@ class SecureHeteroNNHostScheduler(SecureHeteroNNScheduler):
 
             self._switch_status(self._GETHORING)
             self._checkin()
-            time.sleep(1)  # TODO remove me
 
             self._switch_status(self._ID_INTERSECTION)
             self._make_id_intersection()
@@ -703,6 +702,19 @@ class SecureHeteroNNHostScheduler(SecureHeteroNNScheduler):
                                                     requester_id=_event.peer_id)
                 if all(check_in_status.values()):
                     break
+        # it takes seconds to send a response and to consume it in the remote side,
+        # meanwhile, more check in events may arrive soonly. So keep looking for a while.
+        # TODO Ugerly，refactory it!
+        countdown = 10
+        for _event in self.contractor.contract_events(timeout=countdown):
+            if isinstance(_event, CheckinEvent):
+                check_in_status[_event.peer_id] = True
+                self.push_log(f'Welcome a new partner ID: {_event.peer_id}.')
+                self.push_log(f'There are {sum(check_in_status.values())} partners now.')
+                self.contractor.respond_checkin(round=self._round,
+                                                host=self.id,
+                                                nonce=_event.nonce,
+                                                requester_id=_event.peer_id)
         self.push_log('All partners have gethored.')
 
     def _sync_state(self):
@@ -753,7 +765,6 @@ class SecureHeteroNNHostScheduler(SecureHeteroNNScheduler):
         self.infer_model.train()
         self.project_layer.train()
         self.feature_model.train()
-        time.sleep(1)  # TODO remove me
         for _feature_batch, _labels in self.iterate_train_feature(
             self.feature_model, self.train_ids
         ):
@@ -866,7 +877,11 @@ class SecureHeteroNNHostScheduler(SecureHeteroNNScheduler):
             feature_tensor: ts.CKKSTensor
             proj = self._feature_fusion_map[feature_key]
             cipher_W_grad: ts.CKKSTensor = feature_tensor.transpose()
-            cipher_W_grad.mm_(proj.grad).add_(self._epsilon_host)
+            try:
+                cipher_W_grad.mm_(proj.grad).add_(self._epsilon_host)
+            except ValueError:
+                logger.error(f'{proj.grad=}')
+                raise
             self.data_channel.send_stream(source=self.id,
                                           target=_partner,
                                           data_stream=cipher_W_grad.serialize(),
