@@ -25,8 +25,8 @@ from .secure_hetero_nn import (SecureHeteroNNScheduler, _CKKSTensorWrapper,
                                _NoisedWGradWrapper)
 
 
-class SecureHeteroNNCollaboraterScheduler(SecureHeteroNNScheduler):
-    """Schedule the process of a collaborater in a hetero_nn task."""
+class SecureHeteroNNCollaboratorScheduler(SecureHeteroNNScheduler):
+    """Schedule the process of a collaborator in a hetero_nn task."""
 
     _WAITING_FOR_CIPHER_PROJECTION = 'wait_4_proj'
     _SENDING_NOISED_PROJECTION = 'send_proj'
@@ -46,7 +46,7 @@ class SecureHeteroNNCollaboraterScheduler(SecureHeteroNNScheduler):
         :args
             :feature_key
                 A unique key of feature used by the host to distinguish features
-                from collaboraters.
+                from collaborators.
             :project_layer_lr
                 The learning rate of project layer.
             :name
@@ -447,7 +447,7 @@ class SecureHeteroNNCollaboraterScheduler(SecureHeteroNNScheduler):
             model_file_path = self._prepare_task_output()
             self.contractor.upload_task_achivement(aggregator=self.id,
                                                    model_file=model_file_path)
-            self.contractor.notify_collaborater_complete(peer_id=self.id, host=self.host)
+            self.contractor.notify_collaborator_complete(peer_id=self.id, host=self.host)
             self.push_log(f'Task {self.task_id} complete. Byebye!')
         else:
             self.push_log(f'Task {self.task_id} failed. Byebye!')
